@@ -71,7 +71,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 26915743 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 27505028 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -358,15 +358,19 @@ fi
 journalctl=`which journalctl 2> /dev/null | head -n 1`
 
 if [ $? -eq 0 -a -x "$journalctl" ]; then
-    for comm in Xorg Xorg.bin X gdm-x-session; do
+    for match in _COMM=Xorg \
+                 _COMM=Xorg.bin \
+                 _COMM=X \
+                 _COMM=gdm-x-session \
+                 "SYSLOG_IDENTIFIER=systemd-coredump -g nvidia"; do
         for boot in -0 -1 -2; do
-            if journalctl -b $boot -n 1 _COMM=$comm >/dev/null 2>&1; then
+            if journalctl -b $boot -n 1 $match >/dev/null 2>&1; then
                 (
                     echo "____________________________________________"
                     echo ""
-                    echo "journalctl -b $boot _COMM=$comm"
+                    echo "journalctl -b $boot $match"
                     echo ""
-                    journalctl -b $boot _COMM=$comm
+                    journalctl -b $boot $match
                     echo ""
                 ) 2> /dev/null | $GZIP_CMD >> $LOG_FILENAME
             fi
@@ -374,6 +378,21 @@ if [ $? -eq 0 -a -x "$journalctl" ]; then
     done
 fi
 
+# use systemd's coredumpctl to capture X coredumps where applicable
+
+coredumpctl=`which coredumpctl 2> /dev/null | head -n 1`
+
+if [ $? -eq 0 -a -x "$coredumpctl" ]; then
+    cmd="$coredumpctl info COREDUMP_COMM=Xorg COREDUMP_COMM=Xorg.bin COREDUMP_COMM=X"
+    (
+        echo "____________________________________________"
+        echo ""
+        echo "$cmd"
+        $cmd
+        echo ""
+    ) 2> /dev/null | $GZIP_CMD >> $LOG_FILENAME
+fi
+
 # append the X log; also, extract the config file named in the X log
 # and append it; look for X log files with names of the form:
 # /var/log/Xorg.{0,1,2,3,4,5,6,7}.{log,log.old}
@@ -534,6 +553,54 @@ append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
     fi
 ) | $GZIP_CMD >> $LOG_FILENAME
 
+# NUMA information
+
+(
+    echo "____________________________________________"
+    echo ""
+
+    numactl=`which numactl 2> /dev/null | head -n 1`
+
+    if [ $? -eq 0 -a -x "$numactl" ]; then
+	# Get hardware NUMA configuration
+	echo "$numactl -H"
+	echo ""
+	$numactl -H
+    fi
+
+    # Get additional NUMA information
+    filelist="/sys/devices/system/node/has_cpu \
+    	      /sys/devices/system/node/has_memory \
+	      /sys/devices/system/node/has_normal_memory \
+	      /sys/devices/system/node/online \
+	      /sys/devices/system/node/possible"
+
+    # Get GPU NUMA information
+    lspci=`which lspci 2> /dev/null | head -n 1`
+    if [ $? -eq 0 -a -x "$lspci" ]; then
+	gpus=`$lspci -d "10de:*" -s ".0" | awk '{print $1}'`
+	for gpu in $gpus; do
+	    filelist="$filelist \
+	    	      /sys/bus/pci/devices/*$gpu/local_cpulist \
+		      /sys/bus/pci/devices/*$gpu/numa_node"
+	done
+    fi
+
+    for file in $filelist; do
+	echo "____________________________________________"
+	if [ ! -f "$file" ]; then
+	    echo "*** $file does not exist"
+	elif [ ! -r "$file" ]; then
+	    echo "*** $file is not readable"
+	else
+	    echo "*** $file"
+	    echo_metadata "$file"
+	    cat "$file"
+	fi
+	echo ""
+    done
+) | $GZIP_CMD >> $LOG_FILENAME
+
 # lsusb information
 
 (
@@ -600,7 +667,7 @@ append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
     echo ""
     echo "Scanning kernel log files for NVIDIA kernel messages:"
 
-    grep_args="-e NVRM -e nvidia-"
+    grep_args="-e NVRM -e nvidia- -e nvrm-nvlog"
     logfound=0
     search_string_in_logs /var/log/messages "$grep_args" && logfound=1
     search_string_in_logs /var/log/kern.log "$grep_args" && logfound=1
